@@ -1,6 +1,7 @@
 """ Views for Dagobah daemon. """
 
 from flask import render_template, redirect, url_for
+from flask_login import login_required
 
 from dagobah.daemon.daemon import app
 from dagobah.daemon.api import get_jobs
@@ -15,6 +16,7 @@ def index_route():
 
 
 @app.route('/jobs', methods=['GET'])
+@login_required
 def jobs():
     """ Show information on all known Jobs. """
     return render_template('jobs.html',
@@ -22,6 +24,7 @@ def jobs():
 
 
 @app.route('/job/<job_id>', methods=['GET'])
+@login_required
 def job_detail(job_id=None):
     """ Show a detailed description of a Job's status. """
     jobs = get_jobs()
@@ -30,6 +33,7 @@ def job_detail(job_id=None):
 
 
 @app.route('/job/<job_id>/<task_name>', methods=['GET'])
+@login_required
 def task_detail(job_id=None, task_name=None):
     """ Show a detailed description of a specific task. """
     jobs = get_jobs()
